==> ksystemlog-17.12.1.tar.xz: ksystemlog-17.12.1/src/modes/kernel/kernelItemBuilder.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef _KERNEL_ITEM_BUILDER_H_
#define _KERNEL_ITEM_BUILDER_H_

#include <QString>

#include <KLocalizedString>

#include "logging.h"

#include "logLine.h"
#include "logViewWidgetItem.h"
#include "logMode.h"

#include "logModeItemBuilder.h"

class LogLine;

class KernelItemBuilder : public LogModeItemBuilder
{
public:
    KernelItemBuilder() {}

    virtual ~KernelItemBuilder() {}

    QString createFormattedText(LogLine *line) const Q_DECL_OVERRIDE
    {
        QString result;

        QListIterator<QString> it(line->logItems());

        result.append(QLatin1String("<table>"));

        result.append(labelMessageFormat(i18n("Date:"), formatDate(line->time())));
        result.append(labelMessageFormat(i18n("Level:"), line->logLevel()->name()));
        result.append(labelMessageFormat(i18n("Component:"), it.next()));

        result.append(QLatin1String("</table>"));

        return result;
    }
};

#endif // _KERNEL_ITEM_BUILDER_H_

==> ksystemlog-18.12.1.tar.xz: ksystemlog-18.12.1/src/modes/kernel/kernelItemBuilder.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef KERNEL_ITEM_BUILDER_H
#define KERNEL_ITEM_BUILDER_H

#include <QString>

#include <KLocalizedString>

#include "logging.h"

#include "logLine.h"
#include "logViewWidgetItem.h"
#include "logMode.h"

#include "logModeItemBuilder.h"

class LogLine;

class KernelItemBuilder : public LogModeItemBuilder
{
public:
    KernelItemBuilder() {}

    virtual ~KernelItemBuilder() {}

    QString createFormattedText(LogLine *line) const override
    {
        QString result;

        QListIterator<QString> it(line->logItems());

        result.append(QLatin1String("<table>"));

        result.append(labelMessageFormat(i18n("Date:"), formatDate(line->time())));
        result.append(labelMessageFormat(i18n("Level:"), line->logLevel()->name()));
        result.append(labelMessageFormat(i18n("Component:"), it.next()));

        result.append(QLatin1String("</table>"));

        return result;
    }
};

#endif // _KERNEL_ITEM_BUILDER_H
